@@ -33,13 +33,13 @@ class KAddressBookPlugin : public KontactInterface::Plugin
     Q_OBJECT
 
 public:
-    explicit KAddressBookPlugin(KontactInterface::Core *core, const QVariantList &);
+    explicit KAddressBookPlugin(KontactInterface::Core *core, const KPluginMetaData &data, const QVariantList &);
     ~KAddressBookPlugin() override;
 
-    bool isRunningStandalone() const override;
-    int weight() const override;
+    Q_REQUIRED_RESULT bool isRunningStandalone() const override;
+    Q_REQUIRED_RESULT int weight() const override;
 
-    QStringList invisibleToolbarActions() const override;
+    Q_REQUIRED_RESULT QStringList invisibleToolbarActions() const override;
     void shortcutChanged() override;
 
 protected:
@@ -51,4 +51,3 @@ private:
 
     KontactInterface::UniqueAppWatcher *mUniqueAppWatcher = nullptr;
 };
-
